export declare const FOG_PROTO = "fog://";
/**
 * @class
 */
export declare class LambdaURI {
    private readonly _protocol;
    private readonly _regionCountryCode;
    private readonly _project;
    private readonly _lambdaId;
    private readonly _lambdaVersion;
    private _lambdaInstance;
    /**
     * @constructor
     * @param {string} _protocol
     * @param {string} _regionCountryCode
     * @param {string} _project
     * @param {string} _lambdaId
     * @param {string} _lambdaVersion
     * @param {number} _lambdaInstance
     */
    constructor(_protocol: string, _regionCountryCode: string, _project: string, _lambdaId: string, _lambdaVersion: string, _lambdaInstance: number);
    /**
     * Protocol
     * @return {string}
     */
    get protocol(): string;
    /**
     * Region country code of this lambda
     *
     * @return {string}
     */
    get regionCountryCode(): string;
    /**
     * Project in which this lambda belongs
     *
     * @return {string}
     */
    get project(): string;
    /**
     * Identifier of this lambda
     *
     * @return {string}
     */
    get lambdaId(): string;
    /**
     * Version of this lambda
     *
     * @return {string}
     */
    get lambdaVersion(): string;
    /**
     * Instance of this lambda
     *
     * @return {number}
     */
    get lambdaInstance(): number;
    /**
     * Define this lambda instance number
     *
     * @param {number} value
     */
    set lambdaInstance(value: number);
    /**
     * Check if is the same project
     * @param {LambdaURI} other
     * @return {boolean}
     */
    isSameProject(other: LambdaURI): boolean;
    /**
     * Check if is the same lambda
     * @param {LambdaURI} other
     * @return {boolean}
     */
    isSameLambda(other: LambdaURI): boolean;
    /**
     * Check if is the same lambda version
     * @param {LambdaURI} other
     * @return {boolean}
     */
    isSameLambdaVersion(other: LambdaURI): boolean;
    /**
     * Check if is the same lambda instance
     * @param {LambdaURI} other
     * @return {boolean}
     */
    isSameLambdaInstance(other: LambdaURI): boolean;
    /**
     * Verify if this URI's refers to lambda IDs wild card
     * @return {boolean}
     */
    isToAllLambdas(): boolean;
    /**
     * Verify if this URI's refers to lambda version wild card
     * @return {boolean}
     */
    isToAllLambdaVersions(): boolean;
    /**
     * Verify if this URI's refers to lambda instance wild card
     * @return {boolean}
     */
    isToAllLambdaInstances(): boolean;
    /**
     * String URI representation
     *
     * @return {string}
     */
    toString(): string;
    /**
     * Create a new URI matching all lambdas
     * @return {LambdaURI}
     */
    toAllLambdas(): LambdaURI;
    /**
     * Create a new URI matching all lambda versions
     * @return {LambdaURI}
     */
    toAllLambdaVersions(): LambdaURI;
    /**
     * Create a new URI matching all lambda instances
     * @return {LambdaURI}
     */
    toAllLambdaInstances(): LambdaURI;
    /**
     * Match other lambdaURI with this
     * @param {LambdaURI} other
     * @return {boolean}
     */
    match(other: LambdaURI): boolean;
    /**
     * Create a new URI matching all lambdas
     * @param {string} regionCountryCode
     * @param {string} project
     * @return {LambdaURI}
     */
    static allLambdas(regionCountryCode: string, project: string): LambdaURI;
    /**
     * Create a new URI matching all lambda versions
     * @param {string} regionCountryCode
     * @param {string} project
     * @param {string} lambdaId
     * @return {LambdaURI}
     */
    static allLambdaVersions(regionCountryCode: string, project: string, lambdaId: string): LambdaURI;
    /**
     * Create a new URI matching all lambda instances
     * @param {string} regionCountryCode
     * @param {string} project
     * @param {string} lambdaId
     * @param {string} lambdaVersion
     * @return {LambdaURI}
     */
    static allLambdaInstances(regionCountryCode: string, project: string, lambdaId: string, lambdaVersion: string): LambdaURI;
    /**
     * @param {string} uri
     *
     * @return {LambdaURI}
     * @throws TypeError If argument is not string
     * @throws Error If is an invalid URI
     */
    static parseFromString(uri: string): LambdaURI;
    /**
     * Instance from lambda object
     *
     * @param {Object} lambda
     * @param {string} regionCountryCode
     * @return {LambdaURI}
     * @throws TypeError If argument is not object
     * @throws Error If object does have the methods
     */
    static parseFromLambda(lambda: any, regionCountryCode: string): LambdaURI;
}
